@@ -46,6 +46,10 @@
 #include <geometry_msgs/WrenchStamped.h>
 #include <kdl/frames.hpp>
 
+#include <array>
+
+#include "ros/macros.h"
+
 namespace tf2
 {
 
@@ -55,7 +59,7 @@ namespace tf2
  * \deprecated
  */
 inline
-KDL::Frame gmTransformToKDL(const geometry_msgs::TransformStamped& t) __attribute__ ((deprecated));
+ROS_DEPRECATED KDL::Frame gmTransformToKDL(const geometry_msgs::TransformStamped& t);
 inline
 KDL::Frame gmTransformToKDL(const geometry_msgs::TransformStamped& t)
   {
@@ -379,7 +383,7 @@ geometry_msgs::QuaternionStamped toMsg(const tf2::Stamped<tf2::Quaternion>& in)
 
 template <>
 inline
-geometry_msgs::QuaternionStamped toMsg(const tf2::Stamped<tf2::Quaternion>& in)  __attribute__ ((deprecated));
+ROS_DEPRECATED geometry_msgs::QuaternionStamped toMsg(const tf2::Stamped<tf2::Quaternion>& in);
 
 
 //Backwards compatibility remove when forked for Lunar or newer
@@ -407,7 +411,7 @@ void fromMsg(const geometry_msgs::QuaternionStamped& in, tf2::Stamped<tf2::Quate
 
 template<>
 inline
-void fromMsg(const geometry_msgs::QuaternionStamped& in, tf2::Stamped<tf2::Quaternion>& out) __attribute__ ((deprecated));
+ROS_DEPRECATED void fromMsg(const geometry_msgs::QuaternionStamped& in, tf2::Stamped<tf2::Quaternion>& out);
 
 //Backwards compatibility remove when forked for Lunar or newer
 template<>
